.. -*- mode: rst -*-

cppyy: Python-C++ bindings interface based on Cling/LLVM
========================================================

cppyy provides dynamic Python-C++ bindings by leveraging the Cling C++
interpreter and LLVM.
It supports both PyPy and CPython.

Details and performance are described in
`this paper <http://conferences.computer.org/pyhpc/2016/papers/5220a027.pdf>`_.

Full documentation: `cppyy.readthedocs.org <http://cppyy.readthedocs.io/en/latest/>`_.
